{#-
  Header override - adds EPUB download button
-#}
{% set class = "md-header" %}
{% if "navigation.tabs.sticky" in features %}
  {% set class = class ~ " md-header--shadow md-header--lifted" %}
{% elif "navigation.tabs" not in features %}
  {% set class = class ~ " md-header--shadow" %}
{% endif %}
<header class="{{ class }}" data-md-component="header">
  <nav class="md-header__inner md-grid" aria-label="{{ lang.t('header') }}">
    <a href="{{ config.extra.homepage | d(nav.homepage.url, true) | url }}" title="{{ config.site_name | e }}" class="md-header__button md-logo" aria-label="{{ config.site_name }}" data-md-component="logo">
      {% include "partials/logo.html" %}
    </a>
    <label class="md-header__button md-icon" for="__drawer">
      {% set icon = config.theme.icon.menu or "material/menu" %}
      {% include ".icons/" ~ icon ~ ".svg" %}
    </label>
    <div class="md-header__title" data-md-component="header-title">
      <div class="md-header__ellipsis">
        <div class="md-header__topic">
          <span class="md-ellipsis">
            {{ config.site_name }}
          </span>
        </div>
        <div class="md-header__topic" data-md-component="header-topic">
          <span class="md-ellipsis">
            {% if page.meta and page.meta.title %}
              {{ page.meta.title }}
            {% else %}
              {{ page.title }}
            {% endif %}
          </span>
        </div>
      </div>
    </div>
    {% if config.theme.palette %}
      {% if not config.theme.palette is mapping %}
        {% include "partials/palette.html" %}
      {% endif %}
    {% endif %}
    {% if not config.theme.palette is mapping %}
      {% include "partials/javascripts/palette.html" %}
    {% endif %}
    {% if config.extra.alternate %}
      {% include "partials/alternate.html" %}
    {% endif %}
    {% if "material/search" in config.plugins %}
      {% set search = config.plugins["material/search"] | attr("config") %}
      {% if search.enabled %}
        <label class="md-header__button md-icon" for="__search">
          {% set icon = config.theme.icon.search or "material/magnify" %}
          {% include ".icons/" ~ icon ~ ".svg" %}
        </label>
        {% include "partials/search.html" %}
      {% endif %}
    {% endif %}
    {% if config.repo_url %}
      <div class="md-header__source">
        {% include "partials/source.html" %}
      </div>
    {% endif %}
    {# EPUB download button #}
    {% if text_forge_downloads_enabled %}
    <a 
      href="{{ config.site_url | default('', true) }}{{ text_forge_epub_filename }}" 
      class="md-header__button md-icon"
      download
      data-i18n-title="downloads_epub_title"
      title="Download EPUB"
      aria-label="Download EPUB"
    >
      {% include ".icons/material/book-open-variant.svg" %}
    </a>
    {% endif %}
    {# AI-readable link — links to raw GitHub source of current chapter #}
    {% if text_forge_ai_readable_prompt and config.repo_url and page and page.file %}
      {% set _chapter_url = (config.repo_url ~ '/' ~ config.edit_uri ~ page.file.src_path)
          | replace('https://github.com/', 'https://raw.githubusercontent.com/')
          | replace('/blob/', '/refs/heads/') %}
      {% set _query = text_forge_ai_readable_prompt.replace('{url}', _chapter_url) %}
    <a 
      href="{{ text_forge_ai_readable_base_url }}{{ _query | urlencode }}" 
      class="md-header__button md-icon"
      target="_blank"
      rel="noopener noreferrer"
      data-i18n-title="ai_readable_title"
      title="Ask AI about this text"
      aria-label="Ask AI about this text"
    >
      {% include ".icons/material/robot-outline.svg" %}
    </a>
    {% endif %}
  </nav>
  {% if "navigation.tabs.sticky" in features %}
    {% if "navigation.tabs" in features %}
      {% include "partials/tabs.html" %}
    {% endif %}
  {% endif %}
</header>
